# Command line utilities

*libinsitu* provides a set of useful command line utilities (CLI), all starting with `ins-`

 * [ins-transform](ins-transform): Transforms raw data files from various formats into NetCDF 
 * [ins-cat](ins-cat): Query local and remote (OpenDAP) NetCDF, outputs in various format (text, csv, json)
 * [ins-info](ins-info): Dumps meta-data about networks and stations
 * [ins-qc](ins-qc): Process quality checks on solar data, tags the data accordingly and produce graphs for visual quality checks 


```{toctree}
---
hidden:
maxdepth: 1
---
ins-transform
ins-cat
ins-info
ins-qc
```